package com.ruoyi.tc.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.tc.entity.AssetTask;
import com.ruoyi.tc.entity.request.AssetTaskPageRequest;
import com.ruoyi.tc.entity.response.*;
import com.ruoyi.tc.mapper.AssetTaskMapper;
import com.ruoyi.tc.service.*;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 任务主表(AssetTask)表服务实现类
 *
 * @author makejava
 * @since 2024-11-18 13:23:09
 */
@Service("assetTaskService")
public class AssetTaskServiceImpl extends ServiceImpl<AssetTaskMapper, AssetTask> implements AssetTaskService {
    @Resource
    private AssetTaskMapper assetTaskDao;

    @Resource
    private AssetCurrentCpService assetCurrentCpService;

    @Resource
    private AssetBusinessFormCpService assetBusinessFormCpService;

    @Resource
    private AssetSupplyChainCpService assetSupplyChainCpService;


    @Resource
    private AssetBasicNetworkCpService assetBasicNetworkCpService;


    @Resource
    private UnitOtherConcatCpService unitOtherConcatCpService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @Override
    public List<AssetTaskIdResponse> queryById(Integer id) {
        return this.assetTaskDao.queryById(id);
    }

    /**
     * 分页查询
     *
     * @param assetTask   筛选条件
     * @param pageRequest 分页对象
     * @return 查询结果
     */
    @Override
    public Page<AssetTask> queryByPage(Page<AssetTask> assetTask, AssetTaskPageRequest pageRequest) {
        return assetTaskDao.queryByPage(assetTask, pageRequest);
    }

    /**
     * 新增数据
     *
     * @param assetTask 实例对象
     * @return 实例对象
     */
    @Override
    public void insert(AssetTask assetTask) {
        //任务新增
        assetTaskDao.insert(assetTask);
        String[] parts = assetTask.getDwmc().split(",");
        for (String part : parts) {
            //根据单位名称查询资产
            AssetCurrentResponse assetCurrentResponse = assetTaskDao.findByDwmcAssetCurrent(part);
            assetCurrentCpService.save(assetCurrentResponse);
            //新增新监管业务形态
            if (assetCurrentResponse.getXjgywxt() != null) {
                //根据资产id查询新监管业务形态主表id
                int businessId = assetBusinessFormCpService.findByassetId(assetCurrentResponse.getId());
                assetCurrentResponse.getXjgywxt().setId(businessId);
                assetCurrentResponse.getXjgywxt().setAssetId(Long.valueOf(assetCurrentResponse.getId()));
                assetBusinessFormCpService.save(assetCurrentResponse.getXjgywxt());
            }
            if (!assetCurrentResponse.getGylxxList().isEmpty()) {

                for (AssetSupplyChainCpResponse items : assetCurrentResponse.getGylxxList()) {
                    //根据资产id查询供应链主表id
                    int supplyChainId = assetSupplyChainCpService.findByassetId(assetCurrentResponse.getId());
                    items.setAssetId(Long.valueOf(assetCurrentResponse.getId()));
                    items.setId(supplyChainId);
                }
                //新增供应链
                assetSupplyChainCpService.saveBatch(assetCurrentResponse.getGylxxList());
            }
            if (!assetCurrentResponse.getJcwlList().isEmpty()) {
                for (AssetBasicNetworkCpResponse items : assetCurrentResponse.getJcwlList()) {
                    //根据资产id查询基础网络主表id
                    int basicNetworkId = assetBasicNetworkCpService.findByassetId(assetCurrentResponse.getId());
                    items.setAssetId(Long.valueOf(assetCurrentResponse.getId()));
                    items.setId(basicNetworkId);
                }
                //新增基础网络
                assetBasicNetworkCpService.saveBatch(assetCurrentResponse.getJcwlList());
            }
            if (!assetCurrentResponse.getOtherConcat().isEmpty()) {
                for (UnitOtherConcatCpResponse items : assetCurrentResponse.getOtherConcat()) {
                    //根据资产id查询其他联系人主表id
                    int unitOtherConcatId = unitOtherConcatCpService.findByassetId(assetCurrentResponse.getId());
                    items.setAssetId(Long.valueOf(assetCurrentResponse.getId()));
                    items.setConcatId((long) unitOtherConcatId);
                }
                //新增其他联系人
                unitOtherConcatCpService.saveBatch(assetCurrentResponse.getOtherConcat());
            }
        }

    }

    /**
     * 修改数据
     *
     * @param assetTask 实例对象
     * @return 实例对象
     */
    @Override
    public int update(AssetTask assetTask) {
        return this.assetTaskDao.update(assetTask);

    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer id) {
        return this.assetTaskDao.deleteById(id) > 0;
    }
}
